local player = require("player")

-- Display mode settings
base_width = 480
base_height = 270
scale = 3
fullscreen = false
vsync = false
debug = true

function reset_display_mode()
	love.window.setMode(base_width*scale, base_height*scale, {fullscreen=fullscreen, vsync=vsync})
end

function love.load()
	reset_display_mode()
	love.graphics.setDefaultFilter("nearest", "nearest")
	love.graphics.setLineStyle("rough")
	love.graphics.setLineJoin("miter")
	p = player:new(16, 16, "kp8", "kp5", "kp4", "kp6", "space")
end
 
function love.update(dt)
	p:update(dt)
end
 
function love.draw()
	-- Print some information about the display mode
	if debug then
		local fscreen_str = " | Fullscreen: " .. tostring(fullscreen)
		local vsync_str = " | Vsync: " .. tostring(vsync)
		love.graphics.setColor(255, 255, 0)
		love.graphics.print("FPS: " .. tostring(love.timer.getFPS()) .. fscreen_str .. vsync_str, 2, 2)
	end
	
	-- Scale everything up
	love.graphics.push()
		love.graphics.scale(scale, scale)
		p:draw()
	love.graphics.pop()
end

function love.keypressed(key)
	-- Disable/enable debug info and vsync
	if key == "f1" then
		debug = not debug
	elseif key == "f2" then
		vsync = not vsync
		reset_display_mode()
	end
	
	p:keypressed(key)
end

function love.keyreleased(key)
	p:keyreleased(key)
end
