local class = require("middleclass")
local action_stack = require("action_stack")
local point = require("point")
					
local player = class("player")

-- Speed vector enums
player.static.SPEED = 68
player.static.UP_SPEED = point(0, -1)
player.static.DOWN_SPEED = point(0, 1)
player.static.LEFT_SPEED = point(-1, 0)
player.static.RIGHT_SPEED = point(1, 0)
player.static.STOP_SPEED = point(0, 0)

function player:initialize(x, y)
	-- Speed
	self.speed_vector = point(0, 0)
		
	-- Position
	self.pos = point(x, y)

	-- Control keys
	self.up_binding = "up"
	self.down_binding = "down"
	self.left_binding = "left"
	self.right_binding = "right"

	-- Control stack
	self.mov_actions = action_stack:new()
	
	-- Sprite
	self.image = love.graphics.newImage("ship.png")
	self.ox = self.image:getWidth() / 2
	self.oy = self.image:getHeight() / 2
	self.orientation = 0
end

function player:draw()
	love.graphics.setColor(255, 255, 0)
	love.graphics.circle("line", self.pos.x, self.pos.y, 12, 10)
	love.graphics.setColor(255, 255, 255)
	love.graphics.draw(self.image, self.pos.x, self.pos.y, self.orientation, 1, 1, self.ox, self.oy)	
end

function player:update(dt)
	local current_action = self.mov_actions:get_action()
	
	-- Get movement speed_vector
	if current_action == action_stack.UP_ACTION then
		self.speed_vector:set_to_point(player.UP_SPEED)
		self.orientation = 0
	elseif current_action == action_stack.RIGHT_ACTION then
		self.speed_vector:set_to_point(player.RIGHT_SPEED)
		self.orientation = math.pi / 2
	elseif current_action == action_stack.DOWN_ACTION then
		self.speed_vector:set_to_point(player.DOWN_SPEED)
		self.orientation = math.pi
	elseif current_action == action_stack.LEFT_ACTION then
		self.speed_vector:set_to_point(player.LEFT_SPEED)
		self.orientation = -math.pi / 2
	elseif current_action == action_stack.NO_ACTION then
		self.speed_vector:set_to_point(player.STOP_SPEED)
	end

	-- Update position
	self.pos.x = self.pos.x + dt * self.speed_vector.x * player.SPEED
	self.pos.y = self.pos.y + dt * self.speed_vector.y * player.SPEED
end

function player:keypressed(key)
	if key == self.up_binding then
		self.mov_actions:add(action_stack.UP_ACTION)
	elseif key == self.down_binding then
		self.mov_actions:add(action_stack.DOWN_ACTION)
	elseif key == self.left_binding then
		self.mov_actions:add(action_stack.LEFT_ACTION)
	elseif key == self.right_binding then
		self.mov_actions:add(action_stack.RIGHT_ACTION)
	end
end

function player:keyreleased(key)
	if key == self.up_binding then
		self.mov_actions:remove(action_stack.UP_ACTION)
	elseif key == self.down_binding then
		self.mov_actions:remove(action_stack.DOWN_ACTION)
	elseif key == self.left_binding then
		self.mov_actions:remove(action_stack.LEFT_ACTION)
	elseif key == self.right_binding then
		self.mov_actions:remove(action_stack.RIGHT_ACTION)
	end
end

return player
